@@ -17,7 +17,7 @@ sub check_modules(;$)
        $VERBOSE, 
        $HAS_Spreadsheet_ParseExcel,
        $HAS_Compress_Raw_Zlib,
-       $HAS_Spreadsheet_XLSX
+       $HAS_Spreadsheet_ParseXLSX
       );
     $VERBOSE=$_[0];
 
@@ -25,9 +25,9 @@ sub check_modules(;$)
     eval
       {
         require Spreadsheet::ParseExcel;
+	use Spreadsheet::ParseExcel::Utility qw(ExcelFmt);
         $HAS_Spreadsheet_ParseExcel=1;
         print "Loaded Spreadsheet::ParseExcel\n" if $VERBOSE;
-
       };
     eval
       {
@@ -37,9 +37,9 @@ sub check_modules(;$)
       };
     eval
       {
-        require Spreadsheet::XLSX;
-        $HAS_Spreadsheet_XLSX=1;
-        print "Loaded Spreadsheet::XLSX\n" if $VERBOSE;
+        require Spreadsheet::ParseXLSX;
+        $HAS_Spreadsheet_ParseXLSX=1;
+        print "Loaded Spreadsheet::ParseXLSX\n" if $VERBOSE;
       };
 
     if($VERBOSE)
@@ -48,11 +48,11 @@ sub check_modules(;$)
 	  if !$HAS_Spreadsheet_ParseExcel;
         print "ERROR: Unable to load Compress::Raw::Zlib perl module! \n"
 	  if ! $HAS_Compress_Raw_Zlib;
-        print "ERROR: Unable to load Spreadsheet::XLSX perl module! \n"
-	  if ! $HAS_Spreadsheet_XLSX;
+        print "ERROR: Unable to load Spreadsheet::ParseXLSX perl module! \n"
+	  if ! $HAS_Spreadsheet_ParseXLSX;
       }
 
-    return $HAS_Spreadsheet_ParseExcel, $HAS_Compress_Raw_Zlib, $HAS_Spreadsheet_XLSX;
+    return $HAS_Spreadsheet_ParseExcel, $HAS_Compress_Raw_Zlib, $HAS_Spreadsheet_ParseXLSX;
   }
 
 sub check_modules_and_notify()
@@ -60,7 +60,7 @@ sub check_modules_and_notify()
     my( 
        $HAS_Spreadsheet_ParseExcel,
        $HAS_Compress_Raw_Zlib,
-       $HAS_Spreadsheet_XLSX) = check_modules(0);
+       $HAS_Spreadsheet_ParseXLSX) = check_modules(0);
 
     $HAS_Spreadsheet_ParseExcel or
       die("ERROR: Perl module Spreadsheet::ParseExcel cannot be loaded. Exiting.\n");
@@ -68,12 +68,12 @@ sub check_modules_and_notify()
     $HAS_Compress_Raw_Zlib or
       warn("WARNING: Perl module Compress::Raw::Zlib cannot be loaded.\n");
 
-    $HAS_Spreadsheet_XLSX or
-      warn("WARNING: Perl module Spreadsheet::XLSX cannot be loaded.\n");
+    $HAS_Spreadsheet_ParseXLSX or
+      warn("WARNING: Perl module Spreadsheet::ParseXLSX cannot be loaded.\n");
 
-    ($HAS_Compress_Raw_Zlib && $HAS_Spreadsheet_XLSX ) or
+    ($HAS_Compress_Raw_Zlib && $HAS_Spreadsheet_ParseXLSX ) or
       warn("WARNING: Microsoft Excel 2007 'XLSX' formatted files will not be processed.\n");
-    return $HAS_Spreadsheet_ParseExcel, $HAS_Compress_Raw_Zlib, $HAS_Spreadsheet_XLSX;
+    return $HAS_Spreadsheet_ParseExcel, $HAS_Compress_Raw_Zlib, $HAS_Spreadsheet_ParseXLSX;
   }
 
 sub install_modules()
@@ -91,6 +91,8 @@ sub install_modules()
     CPAN::Index->reload();
 
     # set the target install path
+    CPAN::Shell->o("conf", "mbuildpl_arg", 
+		   "PREFIX=$here LIB=$here --prefix $here --install-base $here");
     CPAN::Shell->o("conf", "makepl_arg", 
 		   "PREFIX=$here LIB=$here --prefix $here --install-base $here");
     CPAN::Shell->install("Compress::Raw::Zlib");
@@ -98,7 +100,7 @@ sub install_modules()
     #return 0;
 
     # install the libraries we want
-    for $mod (qw( Compress::Raw::Zlib Spreadsheet::XLSX )){
+    for $mod (qw( Compress::Raw::Zlib Spreadsheet::ParseXLSX )){
         my $obj = CPAN::Shell->expand('Module',$mod);
         $obj->install;
     }
